==> custom-toolbox_25.08.4.tar.xz: BUILD/translations/custom-toolbox_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <location filename="../src/mainwindow.cpp" line="198"/>
        <source>Custom Toolbox</source>
        <translation>Herramientas personalizadas</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Personalizar lanzadores</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Cerrar la aplicación</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>Este es un lanzador personalizado</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Mostrar esta ventana al inicio</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Execution Error</source>
        <translation>Error de ejecución</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <source>Failed to execute command: %1</source>
        <translation>Fallo al ejecutar el comando: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Failed to start program: %1</source>
        <translation>Fallo al iniciar el programa: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>Open List File</source>
        <translation>Abrir archivo de lista</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>List Files (*.list)</source>
        <translation>Archivos de lista (*.list)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>File Selection Error</source>
        <translation>Error de selección de archivos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>No file selected. Application will now exit.</source>
        <translation>No se seleccionó ningún archivo. La aplicación se cerrará.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="305"/>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>File Open Error</source>
        <translation>Error al abrir el archivo</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="306"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation>No se pudo abrir el archivo, ¿quiere intentarlo de nuevo?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>File Not Found</source>
        <translation>Archivo no encontrado</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>The file %1 does not exist.</source>
        <translation>El archivo %1 no existe.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <source>Could not open file: </source>
        <translation>No se pudo abrir el archivo:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="660"/>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="663"/>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>Personalizar lanzadores es una herramienta utilizada para crear un lanzador personalizado</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Derechos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="664"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="671"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>Could not write file: %1</source>
        <translation>No se pudo escribir el archivo %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>File Removal Error</source>
        <translation>Error en la eliminación de archivos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>Could not remove file: %1</source>
        <translation>No se pudo eliminar el archivo %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="70"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <location filename="../src/about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="80"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Esta aplicación se puede utilizar para crear lanzadores personalizados: caja de botones/iconos</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="83"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>No mostrar la casilla &apos;Mostrar este cuadro de diálogo al inicio&apos;</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Ruta completa y nombre del archivo .list que desea cargar para configurar la aplicación</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="95"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="96"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Parece que ha iniciado sesión como root, cierre la sesión e inicie sesión como usuario normal para usar este programa.</translation>
    </message>
</context>
</TS>

==> custom-toolbox_25.11.tar.xz: BUILD/translations/custom-toolbox_es_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <location filename="../src/mainwindow.cpp" line="198"/>
        <source>Custom Toolbox</source>
        <translation>Herramientas personalizadas</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Personalizar lanzadores</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Cerrar la aplicación</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>Este es un lanzador personalizado</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Mostrar esta ventana al inicio</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Execution Error</source>
        <translation>Error de ejecución</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <source>Failed to execute command: %1</source>
        <translation>Fallo al ejecutar el comando: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Failed to start program: %1</source>
        <translation>Fallo al iniciar el programa: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>Open List File</source>
        <translation>Abrir archivo de lista</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>List Files (*.list)</source>
        <translation>Archivos de lista (*.list)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>File Selection Error</source>
        <translation>Error de selección de archivos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>No file selected. Application will now exit.</source>
        <translation>No se seleccionó ningún archivo. La aplicación se cerrará.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="305"/>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>File Open Error</source>
        <translation>Error al abrir el archivo</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="306"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation>No se pudo abrir el archivo, ¿quiere intentarlo de nuevo?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>File Not Found</source>
        <translation>Archivo no encontrado</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>The file %1 does not exist.</source>
        <translation>El archivo %1 no existe.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <source>Could not open file: </source>
        <translation>No se pudo abrir el archivo:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="660"/>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="663"/>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>Personalizar lanzadores es una herramienta utilizada para crear un lanzador personalizado</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Derechos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="664"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="671"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>Could not write file: %1</source>
        <translation>No se pudo escribir el archivo %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>File Removal Error</source>
        <translation>Error en la eliminación de archivos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>Could not remove file: %1</source>
        <translation>No se pudo eliminar el archivo %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="70"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <location filename="../src/about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="80"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Esta aplicación se puede utilizar para crear lanzadores personalizados: caja de botones/iconos</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="83"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>No mostrar la casilla &apos;Mostrar este cuadro de diálogo al inicio&apos;</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Ruta completa y nombre del archivo .list que desea cargar para configurar la aplicación</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="95"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="96"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Parece que ha iniciado sesión como root, cierre la sesión e inicie sesión como usuario normal para usar este programa.</translation>
    </message>
</context>
</TS>
